@@ -172,7 +172,6 @@ void NotesManager::slotNewNote(const QString &name, const QString &text)
                          QString(),
                          i18n("Note Received"),
                          QStringLiteral("knotes"),
-                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_notes_agent"));
     auto job = new NoteShared::CreateNewNoteJob(this, nullptr);
@@ -194,3 +193,5 @@ void NotesManager::updateNetworkListener()
         connect(mListener, &QTcpServer::newConnection, this, &NotesManager::slotAcceptConnection);
     }
 }
+
+#include "moc_notesmanager.cpp"
