@@ -9,8 +9,10 @@
 using namespace NoteShared;
 
 NoteEditor::NoteEditor(QWidget *parent)
-    : KPIMTextEdit::RichTextEditorWidget(new NoteShared::RichTextEditWithAutoCorrection(parent))
+    : TextCustomEditor::RichTextEditorWidget(new NoteShared::RichTextEditWithAutoCorrection(parent))
 {
 }
 
 NoteEditor::~NoteEditor() = default;
+
+#include "moc_noteeditor.cpp"
