@@ -6,13 +6,8 @@
 
 #pragma once
 
-#include "config-noshared.h"
-#include <KPIMTextEdit/RichTextEditor>
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+#include <TextCustomEditor/RichTextEditor>
 namespace TextAutoCorrectionCore
-#else
-namespace TextAutoCorrection
-#endif
 {
 class AutoCorrection;
 }
@@ -24,20 +19,15 @@ class RichTextEditWithAutoCorrectionPrivate;
  * @brief The RichTextEditWithAutoCorrection class
  * @author Laurent Montel <montel@kde.org>
  */
-class RichTextEditWithAutoCorrection : public KPIMTextEdit::RichTextEditor
+class RichTextEditWithAutoCorrection : public TextCustomEditor::RichTextEditor
 {
     Q_OBJECT
 public:
     explicit RichTextEditWithAutoCorrection(QWidget *parent = nullptr);
     ~RichTextEditWithAutoCorrection() override;
 
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
-    Q_REQUIRED_RESULT TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
+    [[nodiscard]] TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
     void setAutocorrection(TextAutoCorrectionCore::AutoCorrection *autocorrect);
-#else
-    Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
-    void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
-#endif
 
     void setAutocorrectionLanguage(const QString &language);
 
