@@ -61,6 +61,7 @@
 #include <QMenu>
 #include <QStyle>
 #if KDEPIM_HAVE_X11
+#include <KWindowInfo>
 #include <KX11Extras>
 #endif
 
@@ -171,14 +172,13 @@ KNotesApp::KNotesApp(QWidget *parent)
 
     // get the most recent XML UI file
     QString xmlFileName(componentName() + QLatin1String("ui.rc"));
-#pragma message("port QT5")
-    QString filter(QStringLiteral("kxmlgui" QT_STRINGIFY(QT_VERSION_MAJOR) "/knotes/")
-                   + xmlFileName); // QT5 = componentData().componentName() + QLatin1Char('/') + xmlFileName;
+#pragma message("port QT6")
+    QString filter(QStringLiteral("kxmlgui5/knotes/") + xmlFileName); // QT5 = componentData().componentName() + QLatin1Char('/') + xmlFileName;
     const QStringList fileList = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, filter)
         + QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, xmlFileName); // QT5 =
-#pragma message("port QT5")
+#pragma message("port QT6")
     // QT5 componentData().dirs()->findAllResources( "data", filter ) +
-#pragma message("port QT5")
+#pragma message("port QT6")
     // QT5 componentData().dirs()->findAllResources( "data", xmlFileName );
     qCDebug(KNOTES_LOG) << " fileList :" << fileList << " filter :" << filter;
     QString doc;
@@ -213,13 +213,7 @@ KNotesApp::KNotesApp(QWidget *parent)
 
     connect(qApp, &QGuiApplication::commitDataRequest, this, &KNotesApp::slotCommitData, Qt::DirectConnection);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setFallbackSessionManagementEnabled(false);
-#endif
     updateNoteActions();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(qApp, &QGuiApplication::paletteChanged, this, &KNotesApp::slotGeneralPaletteChanged);
-#endif
 }
 
 KNotesApp::~KNotesApp()
@@ -243,11 +237,9 @@ void KNotesApp::slotGeneralPaletteChanged()
 
 bool KNotesApp::event(QEvent *e)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (e->type() == QEvent::ApplicationPaletteChange) {
         slotGeneralPaletteChanged();
     }
-#endif
     return QWidget::event(e);
 }
 
@@ -728,3 +720,5 @@ void KNotesApp::slotItemFetchFinished(KJob *job)
         updateSystray();
     }
 }
+
+#include "moc_knotesapp.cpp"
