@@ -24,24 +24,24 @@ KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
     layout->addWidget(label_TabSize, 0, 0, 1, 2);
 
     kcfg_TabSize = new QSpinBox(this);
-    kcfg_TabSize->setObjectName(QStringLiteral("kcfg_TabSize"));
+    kcfg_TabSize->setObjectName(QLatin1StringView("kcfg_TabSize"));
     kcfg_TabSize->setRange(1, 40);
     label_TabSize->setBuddy(kcfg_TabSize);
     layout->addWidget(kcfg_TabSize, 0, 2);
 
     kcfg_AutoIndent = new QCheckBox(i18n("Auto &indent"), this);
-    kcfg_AutoIndent->setObjectName(QStringLiteral("kcfg_AutoIndent"));
+    kcfg_AutoIndent->setObjectName(QLatin1StringView("kcfg_AutoIndent"));
     layout->addWidget(kcfg_AutoIndent, 1, 0, 1, 2);
 
     kcfg_RichText = new QCheckBox(i18n("&Rich text"), this);
-    kcfg_RichText->setObjectName(QStringLiteral("kcfg_RichText"));
+    kcfg_RichText->setObjectName(QLatin1StringView("kcfg_RichText"));
     layout->addWidget(kcfg_RichText, 1, 2);
 
     auto label_Font = new QLabel(i18n("Text font:"), this);
     layout->addWidget(label_Font, 3, 0);
 
     kcfg_Font = new KFontRequester(this);
-    kcfg_Font->setObjectName(QStringLiteral("kcfg_Font"));
+    kcfg_Font->setObjectName(QLatin1StringView("kcfg_Font"));
     kcfg_Font->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
     layout->addWidget(kcfg_Font, 3, 1, 1, 2);
 
@@ -49,7 +49,7 @@ KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
     layout->addWidget(label_TitleFont, 2, 0);
 
     kcfg_TitleFont = new KFontRequester(this);
-    kcfg_TitleFont->setObjectName(QStringLiteral("kcfg_TitleFont"));
+    kcfg_TitleFont->setObjectName(QLatin1StringView("kcfg_TitleFont"));
     kcfg_TitleFont->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
     layout->addWidget(kcfg_TitleFont, 2, 1, 1, 2);
     layout->setRowStretch(4, 1);
