@@ -65,11 +65,7 @@ void KNotesIconView::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton) {
         QListView::mousePressEvent(e);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        m_part->popupRMB(currentItem(), e->pos(), e->globalPos());
-#else
         m_part->popupRMB(currentItem(), e->pos(), e->globalPosition().toPoint());
-#endif
     } else {
         QListView::mousePressEvent(e);
     }
