@@ -64,7 +64,7 @@ KNotesSummaryWidget::KNotesSummaryWidget(KontactInterface::Plugin *plugin, QWidg
 
     KSharedConfigPtr _config = KSharedConfig::openConfig(QStringLiteral("kcmknotessummaryrc"));
 
-    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
+    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group(QStringLiteral("CheckState")), this);
     mModelState->setSelectionModel(mSelectionModel);
 }
 
@@ -204,3 +204,5 @@ QStringList KNotesSummaryWidget::configModules() const
 {
     return QStringList() << QStringLiteral("kcmknotessummary.desktop");
 }
+
+#include "moc_summarywidget.cpp"
