@@ -123,14 +123,14 @@ void KNotePrintSelectedNotesDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(300, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNotePrintSelectedNotesDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNotePrintSelectedNotesDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void KNotePrintSelectedNotesDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNotePrintSelectedNotesDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNotePrintSelectedNotesDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
@@ -140,3 +140,5 @@ void KNotePrintSelectedNotesDialog::slotPreview()
     mPreview = true;
     accept();
 }
+
+#include "moc_knoteprintselectednotesdialog.cpp"
